UrzUI = CreateFrame("Frame", "UrzUI", UIParent);

if ( not UrzOption ) then
   UrzOption = {
      ThickFont = false,
      StackedLog = true,
      AutoSize =  true,
      HideError = true,
      ShowNameplates = true,
      ShowStats = true
   };
end

UrzStats = CreateFrame("Frame", "UrzStats", MainMenuBar);
local time = 0;
local function UpdateStats(self, elapsed)
   time = time+elapsed;
   if ( time >= 0.1 ) then
      time = 0;
      UrzHaste:SetText(math.floor(max(UnitSpellHaste("player"), GetRangedHaste("player"), GetMeleeHaste("player"))).." %");
      UrzCrit:SetText(math.floor(max(
               min(GetSpellCritChance(1), GetSpellCritChance(2), GetSpellCritChance(3), GetSpellCritChance(4), GetSpellCritChance(5), GetSpellCritChance(6), GetSpellCritChance(7)),
               GetCritChance(),
               GetRangedCritChance()
      )).." %");
      if ( UnitLevel("player") >= 80 ) then
         UrzMasteryLabel:SetText("Mastery");
         UrzMastery:SetText(math.floor(GetMasteryEffect()).." %");
      else
         UrzMasteryLabel:SetText(nil);
         UrzMastery:SetText(nil);
      end
      UrzAbsorb:SetText(AbbreviateLargeNumbers(UnitGetTotalAbsorbs("player")));
      UrzPower:SetText(AbbreviateLargeNumbers(max(
               min(GetSpellBonusDamage(1), GetSpellBonusDamage(2), GetSpellBonusDamage(3), GetSpellBonusDamage(4), GetSpellBonusDamage(5), GetSpellBonusDamage(6), GetSpellBonusDamage(7)),
               GetSpellBonusHealing(),
               (select(1, UnitAttackPower("player"))+select(2, UnitAttackPower("player"))+select(3, UnitAttackPower("player"))),
               (select(1, UnitRangedAttackPower("player"))+select(2, UnitRangedAttackPower("player"))+select(3, UnitRangedAttackPower("player")))
      )));
   end
end

UrzNameplates = CreateFrame("Frame", "UrzNameplates", WorldFrame);
local function UpdateNameplates(self, elapsed)
   for i = 1, WorldFrame:GetNumChildren() do
      local frame = select(i, WorldFrame:GetChildren());
      if ( frame:GetName() and frame:GetName():match("NamePlate") ) then
         local plate, name = frame:GetChildren();
         local threat, bg, _, lvl = plate:GetRegions();
         local font = name:GetRegions();
         if ( bg:GetAlpha() > 0 ) then
            bg:SetAlpha(0);
            font:SetFont("Fonts\\ARIALN.TTF", 12, nil);
            font:SetShadowOffset(1, -1);
            lvl:SetFont("Fonts\\ARIALN.TTF", 12, nil);
            lvl:SetShadowOffset(1, -1);
         end
         if ( threat:IsShown() ) then
            font:SetTextColor(1, 0.3, 0, 1);
         else
            font:SetTextColor(1, 1, 1, 1);
         end
         if ( UnitExists("target") and frame:GetAlpha() == 1 ) then
            threat:SetVertexColor(1, 1, 1, 1);
            threat:Show();
         else
            threat:Hide();
         end
         frame:SetAlpha(1);
      end
   end
end

UrzChat = CreateFrame("Frame", "UrzChat", UIParent);
local function SetOptions()
   for i = 1, NUM_CHAT_WINDOWS do
      local cf = _G["ChatFrame"..i];
      if ( cf ) then
         local size = (select(2, cf:GetFont()));
         if ( UrzOption.ThickFont ) then
            cf:SetFont("Interface\\AddOns\\UrzUI\\PT_Sans_Narrow.ttf", size, "OUTLINE");
         else
            cf:SetFont("Fonts\\ARIALN.TTF", size);
         end
      end
   end
   if ( UrzOption.StackedLog ) then
      FCF_UnDockFrame(ChatFrame2);
      FCF_SetLocked(ChatFrame2, false);
      FCF_SetTabPosition(ChatFrame2, 0);
      ChatFrame2:SetSize(ChatFrame1:GetWidth(), 65);
      FCF_SetChatWindowFontSize(nil, ChatFrame2, 12);
      ChatFrame2:ClearAllPoints();
      ChatFrame2:SetPoint("BOTTOMLEFT", ChatFrame1, "TOPLEFT", 0, 44);
      FCF_SavePositionAndDimensions(ChatFrame2);
      FCF_FadeOutChatFrame(ChatFrame2);
      FCF_SetLocked(ChatFrame2, true);
   else
      local size = (select(2, ChatFrame1:GetFont()));
      FCF_DockFrame(ChatFrame2, 2, false);
      FCF_SetChatWindowFontSize(nil, ChatFrame2, size);
   end
   if ( UrzOption.AutoSize ) then
      local function setup()
         ChatFrame1:SetSize(GetScreenWidth()/2-293, 115);
         ChatFrame1:ClearAllPoints();
         ChatFrame1:SetPoint("BOTTOMLEFT", UIParent);
         FCF_SetLocked(ChatFrame1, true);
      end
      setup();
      UrzChat:SetScript("OnEvent", setup);
      UrzChat:RegisterEvent("PLAYER_ENTERING_WORLD");
      UrzChat:RegisterEvent("DISPLAY_SIZE_CHANGED");
      UrzChat:RegisterEvent("UI_SCALE_CHANGED");
      FCF_SetLocked(ChatFrame1, true);
   else
      UrzChat:UnregisterAllEvents();
      UrzChat:SetScript("OnEvent", nil);
      FCF_SetLocked(ChatFrame1, false);
   end
   if ( UrzOption.HideError ) then
      UIErrorsFrame:Hide();
   else
      UIErrorsFrame:Show();
   end
   if ( UrzOption.ShowNameplates ) then
      UrzNameplates:SetScript("OnUpdate", UpdateNameplates);
   else
      UrzNameplates:SetScript("OnUpdate", nil);
   end
   if ( UrzOption.ShowStats) then
      UrzStats:SetScript("OnUpdate", UpdateStats);
      UrzStats:Show();
   else
      UrzStats:SetScript("OnUpdate", nil);
      UrzStats:Hide();
   end
end

local function SetMainMenu()
   for _, value in pairs({"MainMenuBarPageNumber", "ActionBarUpButton", "ActionBarDownButton", "MainMenuBarLeftEndCap", "MainMenuBarRightEndCap", "MainMenuXPBarTextureLeftCap", "MainMenuXPBarTextureMid", "MainMenuXPBarTextureRightCap", "StanceBarLeft", "StanceBarMiddle", "StanceBarRight", "SlidingActionBarTexture0", "SlidingActionBarTexture1", "PossessBackground1", "PossessBackground2", "OverrideActionBarEndCapL", "OverrideActionBarEndCapR", "MainMenuXPBarDiv1", "MainMenuXPBarDiv2", "MainMenuXPBarDiv3", "MainMenuXPBarDiv4", "MainMenuXPBarDiv5", "MainMenuXPBarDiv6", "MainMenuXPBarDiv7", "MainMenuXPBarDiv8", "MainMenuXPBarDiv9", "MainMenuXPBarDiv10", "MainMenuXPBarDiv11", "MainMenuXPBarDiv12", "MainMenuXPBarDiv13", "MainMenuXPBarDiv14", "MainMenuXPBarDiv15", "MainMenuXPBarDiv16", "MainMenuXPBarDiv17", "MainMenuXPBarDiv18", "MainMenuXPBarDiv19", "MainMenuBarTexture0", "MainMenuBarTexture1", "MainMenuBarTexture2", "MainMenuBarTexture3", "ReputationXPBarTexture0", "ReputationXPBarTexture1", "ReputationXPBarTexture2", "ReputationXPBarTexture3", "ReputationWatchBarTexture0", "ReputationWatchBarTexture1", "ReputationWatchBarTexture2", "ReputationWatchBarTexture3", "MainMenuMaxLevelBar0", "MainMenuMaxLevelBar1", "MainMenuMaxLevelBar2", "MainMenuMaxLevelBar3"}) do
      local name = _G[value];
      if ( name ) then
         if ( name:GetObjectType() == "Texture" ) then
            name:SetTexture(nil);
         end
         name:SetAlpha(0);
         name:Hide();
      end
   end
   for _, value in pairs({"StanceBarFrame", "PossessBarFrame", "PetActionBarFrame", "MultiBarLeft", "MultiBarRight", "MultiBarBottomLeft", "MultiBarBottomRight", "MainMenuBar", "MainMenuBarMaxLevelBar", "UIErrorsFrame"}) do
      local name = _G[value];
      if ( name ) then
         name:SetFrameStrata("MEDIUM");
         name:EnableMouse(false);
      end
   end
   for _, value in pairs({"ActionButton", "MultiBarBottomLeftButton", "MultiBarBottomRightButton", "MultiBarLeftButton", "MultiBarRightButton", "StanceButton", "PossessButton", "PetActionButton"}) do
      for i = 1, 12 do
         local name = _G[value..i];
         if ( name ) then
            name:GetNormalTexture():SetPoint("TOPLEFT", name, "TOPLEFT", -12, 12);
            name:GetNormalTexture():SetPoint("BOTTOMRIGHT", name, "BOTTOMRIGHT", 13, -13);
            name:SetSize(36, 36);
            name:SetScale(1);
            for _, value2 in pairs({"FloatingBG", "Name"}) do
               local name2 = _G[name:GetName()..value2];
               if ( name2 ) then
                  name2:SetAlpha(0);
               end
            end
         end
      end
   end
   MainMenuBarVehicleLeaveButton:SetSize(36, 36);
   MainMenuBarVehicleLeaveButton:SetScale(0.7);
   StanceBarFrame:SetScale(0.7);
   PossessBarFrame:SetScale(0.7);
   PetActionBarFrame:SetScale(0.7);
   OverrideActionBar:SetScale(0.7);
   PetBattleFrame:SetScale(0.7);
   MainMenuBar:SetWidth(512);
   MultiBarBottomLeftButton1:ClearAllPoints();
   MultiBarBottomLeftButton1:SetPoint("BOTTOMLEFT", ActionButton1, "TOPLEFT", 0, 6);
   MultiBarBottomRightButton1:ClearAllPoints();
   MultiBarBottomRightButton1:SetPoint("BOTTOMLEFT", MultiBarBottomLeftButton1, "TOPLEFT", 0, 6);
   StanceButton1:ClearAllPoints();
   StanceButton1:SetPoint("BOTTOMLEFT", MultiBarBottomRightButton1, "TOPLEFT", 0, 6);
   PossessButton1:ClearAllPoints();
   PossessButton1:SetPoint("BOTTOMLEFT", MultiBarBottomRightButton1, "TOPLEFT", 0, 6);
   PetActionButton10:ClearAllPoints();
   PetActionButton10:SetPoint("BOTTOMRIGHT", MultiBarBottomRightButton12, "TOPRIGHT", 0, 6);
   for i = 2, 10 do
      _G["StanceButton"..i]:ClearAllPoints();
      _G["StanceButton"..i]:SetPoint("LEFT", _G["StanceButton"..i-1], "RIGHT", 6, 0);
      _G["PetActionButton"..11-i]:ClearAllPoints();
      _G["PetActionButton"..11-i]:SetPoint("RIGHT", _G["PetActionButton"..12-i], "LEFT", -6, 0);
   end
   PossessButton2:ClearAllPoints();
   PossessButton2:SetPoint("LEFT",  PossessButton1, "RIGHT", 6, 0);
   local function setup()
      MainMenuBarVehicleLeaveButton:ClearAllPoints();
      if ( IsPossessBarVisible() ) then
         MainMenuBarVehicleLeaveButton:SetPoint("LEFT", PossessButton2, "RIGHT", 30, 0);
      elseif ( GetNumShapeshiftForms() > 0 ) then
         MainMenuBarVehicleLeaveButton:SetPoint("LEFT", _G["StanceButton"..GetNumShapeshiftForms()], "RIGHT", 30, 0);
      else
         MainMenuBarVehicleLeaveButton:SetPoint("BOTTOMLEFT", MultiBarBottomRightButton1, "TOPLEFT", 0, 6);
      end
   end
   if ( MainMenuBarVehicleLeaveButton:IsShown() ) then
      setup();
   end
   hooksecurefunc("MainMenuBarVehicleLeaveButton_Update", setup);
   local function setup()
      CharacterMicroButton:ClearAllPoints();
      CharacterMicroButton:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", -275, 1);
      PVPMicroButton:ClearAllPoints();
      PVPMicroButton:SetPoint("BOTTOMLEFT", GuildMicroButton, "BOTTOMRIGHT", -3, 0);
   end
   if ( MainMenuBar:IsShown() ) then
      setup();
   end
   MainMenuBar:HookScript("OnShow", setup);
   local function setup()
      MainMenuExpBar:SetSize(300, 13);
      ReputationWatchStatusBar:SetSize(300, 13);
      ReputationWatchBar:SetSize(300, 13);
      ReputationWatchStatusBarText:SetPoint("CENTER", ReputationWatchBarOverlayFrame, "CENTER", 0, 1);
      ReputationWatchBarOverlayFrame:SetFrameStrata("MEDIUM");
      local y = 40;
      MainMenuExpBar:ClearAllPoints();
      MainMenuExpBar:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", -1, y);
      if ( MainMenuExpBar:IsShown() ) then
         y = y+16;
      end
      ReputationWatchBar:ClearAllPoints();
      ReputationWatchBar:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", -1, y);
      if ( ReputationWatchBar:IsShown() ) then
         y = y+16;
      end
      MainMenuBarBackpackButton:ClearAllPoints();
      MainMenuBarBackpackButton:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", -1, y);
   end
   setup();
   hooksecurefunc("ReputationWatchBar_Update", setup);
end

local function SetChatFrames()
   DEFAULT_CHATFRAME_ALPHA = 0;
   CHAT_FRAME_TAB_ALERTING_MOUSEOVER_ALPHA = 0.5;
   CHAT_FRAME_TAB_ALERTING_NOMOUSE_ALPHA = 0.5;
   CHAT_FRAME_TAB_NORMAL_MOUSEOVER_ALPHA = 0.5;
   CHAT_FRAME_TAB_NORMAL_NOMOUSE_ALPHA = 0.5;
   CHAT_FRAME_TAB_SELECTED_MOUSEOVER_ALPHA = 1;
   CHAT_FRAME_TAB_SELECTED_NOMOUSE_ALPHA = 1;
   for i = 1, NUM_CHAT_WINDOWS do
      local cf = _G["ChatFrame"..i];
      if ( cf ) then
         local name = _G["ChatFrame"..i.."EditBox"];
         if ( name and ( name ~= ChatFrame1EditBox ) ) then
            name:SetAllPoints(ChatFrame1EditBox);
         end
         cf:SetClampRectInsets(-35, 35, 38, -35);
         FCF_SetUninteractable(cf, false);
         for _, value in pairs({"Left", "Middle", "Right", "SelectedLeft", "SelectedMiddle", "SelectedRight", "HighlightLeft", "HighlightMiddle", "HighlightRight"}) do
            local name = _G["ChatFrame"..i.."Tab"..value];
            if ( name ) then
               name:SetAlpha(0);
            end
         end
         local name = _G["ChatFrame"..i.."ButtonFrameMinimizeButton"];
         if ( name ) then
            name:HookScript("OnShow", function(self)
                  self:Hide();
            end);
            name:Hide();
         end
         FCF_SetWindowAlpha(cf, DEFAULT_CHATFRAME_ALPHA);
         FCFTab_UpdateAlpha(cf);
      end
   end
   FCFManager_RegisterDedicatedFrame(ChatFrame2, "PET_BATTLE_COMBAT_LOG");
   CombatLogQuickButtonFrame_Custom:SetHeight(0);
   CombatLogQuickButtonFrame_Custom:Hide();
   ChatFrame2:HookScript("OnShow", function(self)
         CombatLogQuickButtonFrame_Custom:SetHeight(0);
         CombatLogQuickButtonFrame_Custom:Hide();
   end);
   for value in pairs(ChatTypeGroup) do
      if ( value ) then
         SetChatColorNameByClass(value, true);
      end
   end
   for i = 1, MAX_WOW_CHAT_CHANNELS do
      local name = "CHANNEL"..i;
      if ( name ) then
         SetChatColorNameByClass(name, true);
      end
   end
end

local function SetStats()
   UrzMasteryLabel = UrzStats:CreateFontString("UrzMasteryLabel", "ARTWORK", "GameFontHighlightSmall");
   UrzCritLabel = UrzStats:CreateFontString("UrzCritLabel", "ARTWORK", "GameFontHighlightSmall");
   UrzHasteLabel = UrzStats:CreateFontString("UrzHasteLabel", "ARTWORK", "GameFontHighlightSmall");
   UrzAbsorbLabel = UrzStats:CreateFontString("UrzAbsorbLabel", "ARTWORK", "GameFontHighlightSmall");
   UrzPowerLabel = UrzStats:CreateFontString("UrzPowerLabel", "ARTWORK", "GameFontHighlightSmall");
   UrzMastery = UrzStats:CreateFontString("UrzMastery", "ARTWORK", "TextStatusBarText");
   UrzCrit = UrzStats:CreateFontString("UrzCrit", "ARTWORK", "TextStatusBarText");
   UrzHaste = UrzStats:CreateFontString("UrzHaste", "ARTWORK", "TextStatusBarText");
   UrzAbsorb = UrzStats:CreateFontString("UrzAbsorb", "ARTWORK", "TextStatusBarText");
   UrzPower = UrzStats:CreateFontString("UrzPower", "ARTWORK", "TextStatusBarText");
   UrzAbsorb:SetFont(STANDARD_TEXT_FONT, 14, "THINOUTLINE");
   UrzPower:SetFont(STANDARD_TEXT_FONT, 18, "THINOUTLINE");
   for _, value in pairs({"UrzAbsorb", "UrzMastery", "UrzCrit", "UrzHaste", "UrzPower"}) do
      local stat = _G[value];
      local name = _G[value.."Label"];
      if ( stat and stat:GetObjectType() == "FontString" and name and name:GetObjectType() == "FontString" ) then
         name:ClearAllPoints();
         name:SetPoint("BOTTOMLEFT", stat, "TOPLEFT", 0, 2);
      end
   end
   UrzCrit:ClearAllPoints();
   UrzCrit:SetPoint("BOTTOMLEFT", UrzHasteLabel, "TOPLEFT", 0, 2);
   UrzMastery:ClearAllPoints();
   UrzMastery:SetPoint("BOTTOMLEFT", UrzCritLabel, "TOPLEFT", 0, 2);
   UrzPower:ClearAllPoints();
   UrzPower:SetPoint("BOTTOMLEFT", UrzHaste, "BOTTOMLEFT", 55, -3);
   UrzAbsorb:ClearAllPoints();
   UrzAbsorb:SetPoint("BOTTOMLEFT", UrzPowerLabel, "TOPLEFT", 0, 2); 
   local function setup()
      UrzHaste:ClearAllPoints();
      if ( StanceBarFrame:IsShown() or PossessBarFrame:IsShown() or MainMenuBarVehicleLeaveButton:IsShown() ) then
         UrzHaste:SetPoint("BOTTOMLEFT", StanceButton1, "TOPLEFT", 0, 6);
      else
         UrzHaste:SetPoint("BOTTOMLEFT", MultiBarBottomRightButton1, "TOPLEFT", 0, 6);
      end
   end
   setup();
   for _, value in pairs({"StanceBarFrame", "PossessBarFrame", "MainMenuBarVehicleLeaveButton"}) do
      local name = _G[value];
      if ( name ) then
         for _, event in pairs({"OnShow", "OnHide"}) do
            name:HookScript(event, setup);
         end
      end
   end
   UrzCritLabel:SetText("Crit");
   UrzHasteLabel:SetText("Haste");
   UrzAbsorbLabel:SetText("Absorbs");
   UrzPowerLabel:SetText("Power");
end

local function SetMisc()
   CompactUnitFrameProfilesGeneralOptionsFrameHeightSlider:SetMinMaxValues(20, 40);
   hooksecurefunc("GameTooltip_SetDefaultAnchor", function (tooltip, parent)
         tooltip:SetOwner(parent, "ANCHOR_NONE");
         tooltip:SetPoint("BOTTOMRIGHT", UIParent, "BOTTOMRIGHT", 0, 140);
   end);
   hooksecurefunc("TextStatusBar_UpdateTextString", function(textStatusBar)
         if ( textStatusBar == TargetFrameHealthBar ) then
            local health = UnitHealth("target") or 0;
            if ( health > 0 ) then
               TargetFrameTextureFrameHealthBarText:SetFormattedText("%s   %i%%", AbbreviateLargeNumbers(health), math.ceil(health/UnitHealthMax("target")*100));
            end
         end
   end);
   UrzRepair = CreateFrame("Frame", "UrzRepair", UIParent);
   UrzRepair:SetScript("OnEvent", function(self, event, ...)
         for bag = 0, 4 do
            for slot = 0, GetContainerNumSlots(bag) do
               local link = GetContainerItemLink(bag, slot);
               if ( link and (select(3, GetItemInfo(link)) == 0) ) then
                  UseContainerItem(bag, slot);
               end
            end
         end
         RepairAllItems(1);
   end);
   UrzRepair:RegisterEvent("MERCHANT_SHOW");
end

local function SetConfig()
   UrzConfig = CreateFrame("Frame", "UrzConfig", UIParent);
   UrzConfig.name = "UrzUI";
   InterfaceOptions_AddCategory(UrzConfig);
   SlashCmdList["UrzSlash"] = function()
      InterfaceOptionsFrame:Show();
      InterfaceOptionsFrame_OpenToCategory("UrzUI");
   end; 
   SLASH_UrzSlash1 = "/urz";
   SLASH_UrzSlash2 = "/urzui";
   text1 = UrzConfig:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge");
   text2 = UrzConfig:CreateFontString(nil, "ARTWORK", "QuestFont_Large");
   box1 = CreateFrame("CheckButton", "UrzConfigBox1", UrzConfig, "UICheckButtonTemplate");
   box2 = CreateFrame("CheckButton", "UrzConfigBox2", UrzConfig, "UICheckButtonTemplate");
   box3 = CreateFrame("CheckButton", "UrzConfigBox3", UrzConfig, "UICheckButtonTemplate");
   box4 = CreateFrame("CheckButton", "UrzConfigBox4", UrzConfig, "UICheckButtonTemplate");
   box5 = CreateFrame("CheckButton", "UrzConfigBox5", UrzConfig, "UICheckButtonTemplate"); 
   box6 = CreateFrame("CheckButton", "UrzConfigBox6", UrzConfig, "UICheckButtonTemplate"); 
   local function setup()
      box1:SetChecked(UrzOption.ThickFont);
      box2:SetChecked(UrzOption.StackedLog);
      box3:SetChecked(UrzOption.AutoSize);
      box4:SetChecked(UrzOption.HideError);
      box5:SetChecked(UrzOption.ShowNameplates);
      box6:SetChecked(UrzOption.ShowStats);
   end
   setup();
   UrzConfig:SetScript("OnShow", setup);
   text1:SetPoint("TOPLEFT", 16, -16);
   text1:SetText("UrzUI Configuration");
   text2:SetJustifyH("RIGHT");
   text2:SetPoint("BOTTOMRIGHT", -16, 16);
   text2:SetText("To my beloved Madelene :) \n\n– Fredrik   ");
   box1:ClearAllPoints();
   box1:SetPoint("TOPLEFT", 16, -40);
   _G[box1:GetName().."Text"]:SetText("Thicker chat font.");
   box1:SetScript("OnClick", function(self, button, down)
         UrzOption.ThickFont = box1:GetChecked();
         SetOptions();
   end);
   box2:ClearAllPoints();
   box2:SetPoint("TOPLEFT", 16, -65);
   _G[box2:GetName().."Text"]:SetText("Stack the combat log above the chat window.");
   box2:SetScript("OnClick", function(self, button, down)
         UrzOption.StackedLog = box2:GetChecked();
         SetOptions();
   end);
   box3:ClearAllPoints();
   box3:SetPoint("TOPLEFT", 16, -90);
   _G[box3:GetName().."Text"]:SetText("Automatically set the size and position of the main chat window.");
   box3:SetScript("OnClick", function(self, button, down)
         UrzOption.AutoSize = box3:GetChecked();
         SetOptions();
   end);
   box4:ClearAllPoints();
   box4:SetPoint("TOPLEFT", 16, -115);
   _G[box4:GetName().."Text"]:SetText("Hide error messages.");
   box4:SetScript("OnClick", function(self, button, down)
         UrzOption.HideError = box4:GetChecked();
         SetOptions();
   end);
   box5:ClearAllPoints();
   box5:SetPoint("TOPLEFT", 16, -140);
   _G[box5:GetName().."Text"]:SetText("Enable UrzUI's nameplates. (Disable this if you want to use another nameplate addon.)");
   box5:SetScript("OnClick", function(self, button, down)
         UrzOption.ShowNameplates = box5:GetChecked();
         SetOptions();
   end);
   box6:ClearAllPoints();
   box6:SetPoint("TOPLEFT", 16, -165);
   _G[box6:GetName().."Text"]:SetText("Enable UrzUI's stats display.");
   box6:SetScript("OnClick", function(self, button, down)
         UrzOption.ShowStats = box6:GetChecked();
         SetOptions();
   end);
end

UrzUI:SetScript("OnEvent", function(self, event, ...)
      if ( not UnitAffectingCombat("player") ) then
         SetMainMenu();
         SetChatFrames();
         SetStats();
         SetMisc();
         SetConfig();
         SetOptions();
         UrzUI:UnregisterAllEvents();
         UrzUI:SetScript("OnEvent", nil);
      end
end);
UrzUI:RegisterEvent("PLAYER_ENTERING_WORLD");
UrzUI:RegisterEvent("PLAYER_REGEN_ENABLED");
